function st=Banach_matches(N)
% input: N successful sample

% Banach's match problem is a classic problem in probability attributed to
% Stefan Banach. Suppose a mathematician carries two matchboxes at all
% times: one in his left pocket and one in his right. Each time he needs a
% match, he is equally likely to take it from either pocket. Suppose he
% reaches into his pocket and discovers that the box picked is empty. If it
% is assumed that each of the matchboxes originally contained N matches,
% what is the probability that there are exactly k matches in the other
% box? Here we propose an algorithm that modelling the process
% of arbirtary picking matches from mathchboxes with equal probability. The
% process will terminate when one of matchboxes get empty

% by Konstantin Ninidze

% "Filling" up matchboxes
n=20;
B1=n;
B2=n;
suc=N;
% Simulation of taking matches from either pocket befor box picked appears to be empty
k=1;
while B1*B2~=0
    p= round(rand);
    if p
        B1=B1-1;
    else
        B2=B2-1;
    end
    k=k+1;
end
% Preparing a figure window 
close
n1=B1;n2=B2;
figure('Color','w');
% set(F,'WindowStyle','docked')
% Drawing one matchbox and pointed out the quantity of matches in it
cube([1 1 1], [1 1 1], 50);
alpha(0.2)
m1=int2str(n1);
text(1.5, 1.5, 1.5,m1,'FontSize',16,...
    'FontWeight','b')
axis on
hold on
% Drawing another matchbox and pointed out the quantity of matches in it
cube([1 1 1]+[2 1.5 0], [1 1 1], 30);
alpha(0.2)
m2=int2str(n2);
text(3.5, 3, 1.5,m2,'FontSize',16,...
    'FontWeight','b','Color','k')
view(15,32)
% Drawing matches 
if n1~=0
    x1=linspace(2.1,2.9,n1);
    for k1=1:length(x1)
        plot3([x1(k1),x1(k1)],[1,2],[1,1],...
            'LineWidth',2)
        plot3([x1(k1),x1(k1)],[2,2],[1,1],'ro')
    end
else 
    x1=linspace(3.1,3.9,n2);
    for k1=1:length(x1)
        plot3([x1(k1),x1(k1)],[1,2],[1,1],...
            'LineWidth',2)
        plot3([x1(k1),x1(k1)],[2,2],[1,1],'ro')
    end
end
% Prepare xlabel and title
if B1==0
    xlabel(['left box become empty in  ',int2str(k-1),' steps']);        
else
    xlabel(['right box become empty in  ',int2str(k-1),' steps']);
end
if k-1==suc
    ht=title('success is riched!');
    set(ht,'FontSize',14,'Color','r')
end
st=k-1;

function h=cube(i,d,c,alpha)
% function to draw a 3-D cube in a 3-D plot
% cube(start,size,color,alpha);

switch(nargin),
case 0
disp('Too few arguements for cube');
return;
case 1
l=1; %default length of side of cube is 1
c='b'; %default color of cube is blue
case 2,
c='b';
case 3,
alpha=1;
case 4,
%do nothing
otherwise
disp('Too many arguements for cube');
end;
x=[i(1)+[0 0 0 0 d(1) d(1) d(1) d(1)]; ...
i(2)+[0 0 d(2) d(2) 0 0 d(2) d(2)]; ...
i(3)+[0 d(3) 0 d(3) 0 d(3) 0 d(3)]]';
for n=1:3,
if n==3,
x=sortrows(x,[n,1]);
else
x=sortrows(x,[n n+1]);
end;
temp=x(3,: );
x(3,: )=x(4,: );
x(4,: )=temp;
h=patch(x(1:4,1),x(1:4,2),x(1:4,3),c);
set(h,'FaceAlpha',alpha);
temp=x(7,: );
x(7,: )=x(8,: );
x(8,: )=temp;
h=patch(x(5:8,1),x(5:8,2),x(5:8,3),c);
set(h,'FaceAlpha',alpha);
end;
view(-44,26)
